macro_rules! plug_fs {
($state:expr, $($wasm:ident),* $(,)?) => { ... };
(@inner, $state:expr, $($wasm:ident),* $(,)?) => { ... };
}Expand description
Plugs the file system ecosystem by defining necessary handlers.
macro_rules! plug_fs {
($state:expr, $($wasm:ident),* $(,)?) => { ... };
(@inner, $state:expr, $($wasm:ident),* $(,)?) => { ... };
}Plugs the file system ecosystem by defining necessary handlers.